<?php
function clearSelectionTopics(&$tof) {
	$selection = $tof->ct->getSelection($tof->uid);
	foreach($selection as $pictureID) {
		$tof->ct->clearTopics($pictureID);
	}
}

function setSelectionTopics(&$tof,$topics) {
	require_once("actions/addSelectionToTopic.php");
	clearSelectionTopics($tof);
	foreach($topics as $topicID) {
		addSelectionToTopic($tof,$topicID);
	}
}

function addSelectionToTopics(&$tof,$topics) {
	require_once("actions/addSelectionToTopic.php");
	foreach($topics as $topicID) {
		addSelectionToTopic($tof,$topicID);
	}
}

function removeSelectionFromTopics(&$tof,$topics) {
	require_once("actions/removeSelectionFromTopic.php");
	foreach($topics as $topicID) {
		removeSelectionFromTopic($tof,$topicID);
	}
}
?>